Method of Characteristics
=========================

.. currentmodule:: scarabee

.. autoclass:: scarabee.MOCDriver

.. autoclass:: scarabee.BoundaryCondition
    :members:

.. autoclass:: scarabee.SimulationMode
    :members:

.. autoclass:: scarabee.CMFD

.. autoclass:: scarabee.P1CriticalitySpectrum

.. autoclass:: scarabee.B1CriticalitySpectrum

Polar Quadratures
-----------------

.. autoclass:: scarabee.PolarQuadrature

.. autoclass:: scarabee.YamamotoTabuchi2

.. autoclass:: scarabee.YamamotoTabuchi4

.. autoclass:: scarabee.YamamotoTabuchi6

.. autoclass:: scarabee.Legendre2

.. autoclass:: scarabee.Legendre4

.. autoclass:: scarabee.Legendre6

.. autoclass:: scarabee.Legendre8

.. autoclass:: scarabee.Legendre10

.. autoclass:: scarabee.Legendre12
